==> lms-1.0pre1.tar.gz: lms/lib/TipOfTheDay.php <==
<?

/*
 * LMS version 1.0
 *
 *  (C) Copyright 2002 Rulez.PL Development Team
 *  (C) Copyright 2001-2002 NetX ACN
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: TipOfTheDay.php,v 1.2 2002/11/30 02:38:43 lukasz Exp $
 */

$tipoftheday[] = "Moesz si pokaleczy wymachujc siekier?";
$tipoftheday[] = "Komputer nie podczony do rda zasilania zdecydowanie odmwi dziaania.";
$tipoftheday[] = "Dowiadczenie to co, co zdobywasz tu po chwili w ktrej go potrzebowae.";
$tipoftheday[] = "Najlepsz metod do zainspirowania odkrywczych myli, jest zaklejenie koperty.";
$tipoftheday[] = "Wszystko zabiera znacznie wicej czasu, ni by si wydawao.";
$tipoftheday[] = "Zawsze kiedy masz wanie co zrobi, okazuje si, e najpierw musisz zrobi co innego.";
$tipoftheday[] = "Kade rozwizanie rodzi nowe problemy.";
$tipoftheday[] = "Gupcy s tak pomysowi, e niemoliwe jest stworzenie czego, z czym kady gupi sobie poradzi.";
$tipoftheday[] = "Matka Natura jest suk.";
$tipoftheday[] = "Rzeczy ulegaj zniszczeniu, wprost proporcjonalnie do swej wartoci.";
$tipoftheday[] = "Wszystkie sprawy szlag trafia jednoczenie.";
$tipoftheday[] = "Jeeli wydaje ci si, e ju gorzej by nie moe - na pewno bdzie.";
$tipoftheday[] = "Zawsze, kiedy wydaje ci si, e bdzie dobrze - kompletnie si mylisz.";
$tipoftheday[] = "Zawsze, kiedy wydaje ci si, e bdzie le te si mylisz - bdzie jeszcze gorzej.";
$tipoftheday[] = "Bardzo duo mona zauway, gdy si patrzy.";
$tipoftheday[] = "Jeli co si wydarza to znaczy, e jest to moliwe. Zatem w walce midzy tob, a wiatem, sta po stronie wiata.";
$tipoftheday[] = "W poszukiwaniu rozwizania problemu, najbardziej pomocna jest znajomo odpowiedzi.";
$tipoftheday[] = "Kady przedmiot niezalenie od pooenia, moe w dowolnej chwili zadziaa w zupenie nieoczekiwany sposb z przyczyn, ktre s albo cakowicie niejasne, albo zupenie tajemnicze.";
$tipoftheday[] = "Wymiary bd zawsze podane w najmniej uytecznych jednostkach.";
$tipoftheday[] = "Kady przewd przycity na dugo, okae si za krtki.";
$tipoftheday[] = "Stopie gupoty twojego postpowania, jest wprost proporcjonalny do liczby przygldajcych ci si osb.";
$tipoftheday[] = "Prawdopodobiestwo wyczerpania si baterii, jest wprost-proporcjonalne do zapotrzebowania na kalkulator.";
$tipoftheday[] = "Ciar upuszczonej czci jest wprost proporcjonalny do ceny obszaru uderzonego.";
$tipoftheday[] = "To czego szukasz, znajdziesz w ostatnim spord moliwych miejsc.";
$tipoftheday[] = "Wniosek to punkt, w ktrym nie masz ju siy dalej myle.";
$tipoftheday[] = "To co moe si nie uda, nie uda si na pewno.";
$tipoftheday[] = "Cztery zjawiska blokuj postp ludzkoci - ignorancja, gupota, komitety normalizacyjne, oraz ludzie sprzedajcy komputery.";
$tipoftheday[] = "Istniej trzy rodzaje kamstw - kamstwa odruchowe, powszechne oraz testy komputerowe.";
$tipoftheday[] = "Czowiek pracujcy z komputerem, nie postpuje zgodnie z wymaganiami komputera.";
$tipoftheday[] = "Systemy odporne na idiotw, obsugiwane s wanie przez nich.";
$tipoftheday[] = "Rozoenie dowolnego urzdzenia na czci jest proste, ponowne jego zoenie, tak eby dziaao, jest niemoliwe.";
$tipoftheday[] = "Kady skomplikowany monta wymaga trzech rk.";
$tipoftheday[] = "Kady prosty monta wymaga czterech rk.";
$tipoftheday[] = "Sprawy pozostawione same sobie, zmieniaj si ze zych na jeszcze gorsze.";
$tipoftheday[] = "Wszystkie komputery PC s kompatybilne, ale niektre s kompatybilniejsze od innych. Twj jest zawsze mniej kompatybilny.";
$tipoftheday[] = "Pust dyskietk moesz przeszukiwa dugo i bezskutecznie. Dugo i bezskutecznie moesz przeszukiwa take pen dyskietk. Wniosek - kad dyskietk moesz przeszukiwa dugo i bezskutecznie.";
$tipoftheday[] = "Komputer suy do tego aby uatwi ci prac, ktrej bez niego w ogle by nie mia.";
$tipoftheday[] = "Dla komputera nie ma rzeczy niemoliwych z wyjtkiem tych, ktrych od niego wymagamy.";
$tipoftheday[] = "W wiecie komputerw adna awaria si nie koczy, poniewa przechodzi zawsze w nastpn.";
$tipoftheday[] = "Awaria komputera wyczekuje cierpliwie na najbardziej niedogodny moment, aby bezlitonie zaatakowa.";
$tipoftheday[] = "W pracy z komputerem, opieranie si na jakichkolwiek zasadach jest bdem.";
$tipoftheday[] = "Drobne awarie nie isniej, jeeli miaa jednak miejsce drobna awaria, oznacza to, e nie poznae jeszcze jej rzeczywistych rozmiarw.";
$tipoftheday[] = "Im doskonalej program wykonuje swoje funkcje, tym dotkliwiej ci zawiedzie. Kady inny program zawodzi tak samo dotkliwie. Tylko niepotrzebny nikomu program, dziaa bez zakce.";
$tipoftheday[] = "Masz zawsze o jeden wirus wicej ni sdzisz.";
$tipoftheday[] = "Program kalkulacyjny, ktry daje waciwy i przyjazny wynik - kamie.";
$tipoftheday[] = "Wyjtki s liczniejsze od regu. Od wszystkich uznanych wyjtkw isniej wyjtki.";
$tipoftheday[] = "Klientowi nigdy nie przyjdzie na myl ile kosztuje projekt, tylko ile mona na tym projekcie zaoszczdzi. Jeeli udao ci si wprowadzi w programie wymagane przez klienta poprawki, wtedy on z nich zrezygnuje. aden klient nie wie czego waciwie chce. Kady klient wie dokadnie czego nie chce. aden klient nie chce tego co masz ju gotowe. Nie wie take co chciaby mie zamiast tego. Klient, ktry najmniej paci, marudzi najwicej. Klient da najwikszych zmian dokadnie wtedy, kiedy produkt jest ju gotowy.";
$tipoftheday[] = "Na polecenie \"napisz tak lub nie\" uytkownik wpisuje \"tak lub nie\". Na polecenie \"wcinij Enter\" uytkownik wpisuje \"Enter\". Na polecenie \"nacinij dowolny klawisz\", uytkownik naciska na klawisz \"reset\". Wniosek: Nie ma programw cakowicie idiotoodpornych.";
$tipoftheday[] = "W zespole programistw kady ma genialny plan rozwizania problemu. Wszystkie plany si wzajemnie wykluczaj i aden nie prowadzi do poprawnego rozwizania. Liczba osb w zespole programistycznym ma tendencje wzrastajce, niezalenie od iloci pracy.";

mt_srand ((double) microtime()* 100000000);
$layout[tip] = $tipoftheday[mt_rand(0,sizeof($tipoftheday)-1)];

==> lms-1.1.2b.tar.gz: lms/lib/TipOfTheDay.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: TipOfTheDay.php,v 1.16 2003/08/24 13:12:54 lukasz Exp $
 */

$tipoftheday[] = "Moesz si pokaleczy wymachujc siekier?";
$tipoftheday[] = "Komputer nie podczony do rda zasilania zdecydowanie odmwi dziaania.";
$tipoftheday[] = "Dowiadczenie to co, co zdobywasz tu po chwili w ktrej go potrzebowae.";
$tipoftheday[] = "Najlepsz metod do zainspirowania odkrywczych myli, jest zaklejenie koperty.";
$tipoftheday[] = "Wszystko zabiera znacznie wicej czasu, ni by si wydawao.";
$tipoftheday[] = "Zawsze kiedy masz wanie co zrobi, okazuje si, e najpierw musisz zrobi co innego.";
$tipoftheday[] = "Kade rozwizanie rodzi nowe problemy.";
$tipoftheday[] = "Gupcy s tak pomysowi, e niemoliwe jest stworzenie czego, z czym kady gupi sobie poradzi.";
$tipoftheday[] = "Matka Natura jest suk.";
$tipoftheday[] = "Rzeczy ulegaj zniszczeniu, wprost proporcjonalnie do swej wartoci.";
$tipoftheday[] = "Wszystkie sprawy szlag trafia jednoczenie.";
$tipoftheday[] = "Jeeli wydaje ci si, e ju gorzej by nie moe - na pewno bdzie.";
$tipoftheday[] = "Zawsze, kiedy wydaje ci si, e bdzie dobrze - kompletnie si mylisz.";
$tipoftheday[] = "Zawsze, kiedy wydaje ci si, e bdzie le te si mylisz - bdzie jeszcze gorzej.";
$tipoftheday[] = "Bardzo duo mona zauway, gdy si patrzy.";
$tipoftheday[] = "Jeli co si wydarza to znaczy, e jest to moliwe. Zatem w walce midzy tob, a wiatem, sta po stronie wiata.";
$tipoftheday[] = "W poszukiwaniu rozwizania problemu, najbardziej pomocna jest znajomo odpowiedzi.";
$tipoftheday[] = "Kady przedmiot niezalenie od pooenia, moe w dowolnej chwili zadziaa w zupenie nieoczekiwany sposb z przyczyn, ktre s albo cakowicie niejasne, albo zupenie tajemnicze.";
$tipoftheday[] = "Wymiary bd zawsze podane w najmniej uytecznych jednostkach.";
$tipoftheday[] = "Kady przewd przycity na dugo, okae si za krtki.";
$tipoftheday[] = "Stopie gupoty twojego postpowania, jest wprost proporcjonalny do liczby przygldajcych ci si osb.";
$tipoftheday[] = "Prawdopodobiestwo wyczerpania si baterii, jest wprost-proporcjonalne do zapotrzebowania na kalkulator.";
$tipoftheday[] = "Ciar upuszczonej czci jest wprost proporcjonalny do ceny obszaru uderzonego.";
$tipoftheday[] = "To czego szukasz, znajdziesz w ostatnim spord moliwych miejsc.";
$tipoftheday[] = "Wniosek to punkt, w ktrym nie masz ju siy dalej myle.";
$tipoftheday[] = "To co moe si nie uda, nie uda si na pewno.";
$tipoftheday[] = "Cztery zjawiska blokuj postp ludzkoci - ignorancja, gupota, komitety normalizacyjne, oraz ludzie sprzedajcy komputery.";
$tipoftheday[] = "Istniej trzy rodzaje kamstw - kamstwa odruchowe, powszechne oraz testy komputerowe.";
$tipoftheday[] = "Czowiek pracujcy z komputerem, nie postpuje zgodnie z wymaganiami komputera.";
$tipoftheday[] = "Systemy odporne na idiotw, obsugiwane s wanie przez nich.";
$tipoftheday[] = "Rozoenie dowolnego urzdzenia na czci jest proste, ponowne jego zoenie, tak eby dziaao, jest niemoliwe.";
$tipoftheday[] = "Kady skomplikowany monta wymaga trzech rk.";
$tipoftheday[] = "Kady prosty monta wymaga czterech rk.";
$tipoftheday[] = "Sprawy pozostawione same sobie, zmieniaj si ze zych na jeszcze gorsze.";
$tipoftheday[] = "Wszystkie komputery PC s kompatybilne, ale niektre s kompatybilniejsze od innych. Twj jest zawsze mniej kompatybilny.";
$tipoftheday[] = "Pust dyskietk moesz przeszukiwa dugo i bezskutecznie. Dugo i bezskutecznie moesz przeszukiwa take pen dyskietk. Wniosek - kad dyskietk moesz przeszukiwa dugo i bezskutecznie.";
$tipoftheday[] = "Komputer suy do tego aby uatwi ci prac, ktrej bez niego w ogle by nie mia.";
$tipoftheday[] = "Dla komputera nie ma rzeczy niemoliwych z wyjtkiem tych, ktrych od niego wymagamy.";
$tipoftheday[] = "W wiecie komputerw adna awaria si nie koczy, poniewa przechodzi zawsze w nastpn.";
$tipoftheday[] = "Awaria komputera wyczekuje cierpliwie na najbardziej niedogodny moment, aby bezlitonie zaatakowa.";
$tipoftheday[] = "W pracy z komputerem, opieranie si na jakichkolwiek zasadach jest bdem.";
$tipoftheday[] = "Drobne awarie nie isniej, jeeli miaa jednak miejsce drobna awaria, oznacza to, e nie poznae jeszcze jej rzeczywistych rozmiarw.";
$tipoftheday[] = "Im doskonalej program wykonuje swoje funkcje, tym dotkliwiej ci zawiedzie. Kady inny program zawodzi tak samo dotkliwie. Tylko niepotrzebny nikomu program, dziaa bez zakce.";
$tipoftheday[] = "Masz zawsze o jeden wirus wicej ni sdzisz.";
$tipoftheday[] = "Program kalkulacyjny, ktry daje waciwy i przyjazny wynik - kamie.";
$tipoftheday[] = "Wyjtki s liczniejsze od regu. Od wszystkich uznanych wyjtkw isniej wyjtki.";
$tipoftheday[] = "Klientowi nigdy nie przyjdzie na myl ile kosztuje projekt, tylko ile mona na tym projekcie zaoszczdzi. Jeeli udao ci si wprowadzi w programie wymagane przez klienta poprawki, wtedy on z nich zrezygnuje. aden klient nie wie czego waciwie chce. Kady klient wie dokadnie czego nie chce. aden klient nie chce tego co masz ju gotowe. Nie wie take co chciaby mie zamiast tego. Klient, ktry najmniej paci, marudzi najwicej. Klient da najwikszych zmian dokadnie wtedy, kiedy produkt jest ju gotowy.";
$tipoftheday[] = "Na polecenie \"napisz tak lub nie\" uytkownik wpisuje \"tak lub nie\". Na polecenie \"wcinij Enter\" uytkownik wpisuje \"Enter\". Na polecenie \"nacinij dowolny klawisz\", uytkownik naciska na klawisz \"reset\". Wniosek: Nie ma programw cakowicie idiotoodpornych.";
$tipoftheday[] = "W zespole programistw kady ma genialny plan rozwizania problemu. Wszystkie plany si wzajemnie wykluczaj i aden nie prowadzi do poprawnego rozwizania. Liczba osb w zespole programistycznym ma tendencje wzrastajce, niezalenie od iloci pracy.";
$tipoftheday[] = "01:04 < [hunter]> robi dokumentacje ?
01:04 < [hunter]> :)
01:04 <@Warden> dokumentacj? rb
01:04 <@Warden> ;)
01:04 <@Warden> Baseciq:: jest chtny!
01:04 <@Warden> ;)
01:05 <@Baseciq> zwicie go!!!!!!!!!
01:05 <@Baseciq> szybko!!!
01:05 <@Baseciq> bo ucieknie!!!
01:06 <@agaran> :>
01:08 <@agaran> :>>> Hunterq uwazaj";

mt_srand ((double) microtime()* 100000000);
$layout[tip] = $tipoftheday[mt_rand(0,sizeof($tipoftheday)-1)];

/*
 * $Log: TipOfTheDay.php,v $
 * Revision 1.16  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.15  2003/08/18 16:57:00  lukasz
 * - more cvs tags :>
 *
 */

?>
